@@ -1,13 +1,13 @@
 import json
 import string
-import uuid
 from datetime import datetime
 from enum import Enum
 
 from cloudevents.http import CloudEvent, to_json
-from flask import g
 from rabbitmq_pika_flask import RabbitMQ
 
+from Job import Job
+
 
 class Status(Enum):
     QUEUED = "queued"
@@ -28,21 +28,14 @@ class JobExtension:
         mediafile_id=None,
         parent_job_id=None,
     ):
-        new_job = {
-            "job_type": job_type,
-            "job_info": job_info,
-            "status": Status.QUEUED.value,
-            "start_time": str(datetime.utcnow()),
-            "user": g.oidc_token_info["email"]
-            if hasattr(g, "oidc_token_info")
-            else "default_uploader",
-            "asset_id": "" if asset_id is None else asset_id,
-            "mediafile_id": "" if mediafile_id is None else mediafile_id,
-            "parent_job_id": "" if parent_job_id is None else parent_job_id,
-            "completed_jobs": 0,
-            "amount_of_jobs": 1,
-            "identifiers": [uuid.uuid1().hex],
-        }
+        new_job = Job(
+            job_type=job_type,
+            job_info=job_info,
+            asset_id=asset_id,
+            mediafile_id=mediafile_id,
+            parent_job_id=parent_job_id,
+        )
+
         self.__send_cloud_event(new_job, "dams.job_created")
         return new_job
 
@@ -57,32 +50,33 @@ class JobExtension:
     ):
 
         if asset_id is not None:
-            job["asset_id"] = asset_id
+            job.asset_id = asset_id
         if mediafile_id is not None:
-            job["mediafile_id"] = mediafile_id
+            job.mediafile_id = mediafile_id
         if parent_job_id is not None:
-            job["parent_job_id"] = parent_job_id
+            job.parent_job_id = parent_job_id
         if amount_of_jobs is not None:
-            job["amount_of_jobs"] = amount_of_jobs
+            job.amount_of_jobs = amount_of_jobs
         if count_up_completed_jobs:
-            job["completed_jobs"] = job["completed_jobs"] + 1
-        job["status"] = Status.IN_PROGRESS.value
+            job.count_up_completed_jobs()
+        job.status = Status.IN_PROGRESS.value
         self.__send_cloud_event(job, "dams.job_changed")
         return job
 
     def finish_job(self, job, parent_job=None):
-        job["status"] = Status.FINISHED.value
-        job["completed_jobs"] = job["amount_of_jobs"]
-        job["end_time"] = str(datetime.utcnow())
-        if job["parent_job_id"] not in ["", None] and parent_job is not None:
+        job.finish(parent_job)
+        job.status = Status.FINISHED.value
+        job.completed_jobs = job.amount_of_jobs
+        job.end_time = str(datetime.utcnow())
+        if job.parent_job_id not in ["", None] and parent_job is not None:
             self.progress_job(parent_job, count_up_completed_jobs=True)
         self.__send_cloud_event(job, "dams.job_changed")
         return job
 
     def fail_job(self, job, error_message=""):
-        job["status"] = Status.FAILED.value
-        job["end_time"] = str(datetime.utcnow())
-        job["error_message"] = error_message
+        job.status = Status.FAILED.value
+        job.end_time = str(datetime.utcnow())
+        job.error_message = error_message
         self.__send_cloud_event(job, "dams.job_changed")
         return job
 
